@@ -121,6 +121,7 @@ def select_sql(
     constraints: Optional[Constraints] = None,
     *,
     columns: str = "*",
+    group_by: Optional[str] = None,
     order_by: Optional[str] = None,
     limit: Optional[LimitOffset] = None,
 ) -> SQL:
@@ -139,6 +140,9 @@ def select_sql(
     if constraint_sql:
         sql = "{} where {}".format(sql, constraint_sql)
 
+    if group_by:
+        sql = "{} group by {}".format(sql, group_by)
+
     if order_by:
         sql = "{} order by {}".format(sql, order_by)
 
@@ -166,7 +170,7 @@ def insert_sql(
     if isinstance(assignments, list):
         assign = assignments
     else:
-        assign = [(k, v) for (k, v) in assignments.items()]
+        assign = list(assignments.items())
 
     columns = ", ".join(c for (c, _) in assign)
     placeholder_list = []
@@ -192,6 +196,25 @@ def insert_sql(
     return (sql, params)
 
 
+def insert_many_sql(
+    table_name: str,
+    assignments_list: List[InsertAssignments],
+    *,
+    returning: Optional[str] = None,
+) -> SQL:
+    """Builds out SQL and params for insert many."""
+    one_sql: Optional[str] = None
+    params_list = []
+
+    for assignments in assignments_list:
+        (sql, params) = insert_sql(table_name, assignments, returning=returning)
+        if not one_sql:
+            one_sql = sql
+        params_list.append(params)
+
+    return (one_sql, params_list)
+
+
 def update_sql(
     table_name: str,
     assignments: Assignments,
