@@ -1,5 +1,5 @@
 """Contains util methods."""
-from typing import Any, List
+from typing import List
 
 from apgw.constraint import BinaryConstraint, Literal
 from apgw.types import SQL, Params
@@ -16,7 +16,7 @@ def constraint_list_to_sql(
     """Turns a list of constraints into a (sql, params) pair."""
     parts: List[str] = []
     params: Params = []
-    placeholder = 1
+    placeholder = offset + 1
 
     for constraint in constraints:
         if constraint.value is None and handle_null:
@@ -55,7 +55,7 @@ def constraint_list_to_sql(
             else:
                 parts.append(
                     "{} {} ${}".format(
-                        constraint.column, constraint.operator, placeholder + offset
+                        constraint.column, constraint.operator, placeholder
                     )
                 )
                 params.append(constraint.value)
